package net.wanji.opt.cache;

import lombok.extern.slf4j.Slf4j;
import net.wanji.common.framework.Constants;
import net.wanji.opt.dao.mapper.CrossPhaseMapper;
import net.wanji.opt.po.base.CrossPhasePO;
import org.springframework.boot.CommandLineRunner;
import org.springframework.stereotype.Component;
import org.springframework.util.CollectionUtils;

import javax.annotation.Resource;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * @author duanruiming
 * @date 2023/03/06 15:03
 */
@Component
@Slf4j
public class CrossPhaseInfoCache implements CommandLineRunner {

    @Resource
    CrossPhaseMapper crossPhaseMapper;

    private static Map<String, List<CrossPhasePO>> crossPhaseInfoMap = new HashMap<>();

    public static Map<String, List<CrossPhasePO>> getCrossPhaseInfoCache() {
        return crossPhaseInfoMap;
    }

    public static List<CrossPhasePO> getCrossPhaseCacheByCrossId(String crossId) {
        if (!crossPhaseInfoMap.isEmpty()) {
            return crossPhaseInfoMap.get(crossId);
        }
        return Collections.EMPTY_LIST;
    }

    public void refresh() {
        init();
    }

    @Override
    public void run(String... args) throws Exception {
        init();
    }

    public void init() {
        List<CrossPhasePO> crossPhasePOS = crossPhaseMapper.listCrossPhase(Constants.SystemParam.NULL, Constants.SystemParam.NULL);
        if (!CollectionUtils.isEmpty(crossPhasePOS)) {
            crossPhaseInfoMap = crossPhasePOS.stream().collect(Collectors.groupingBy(CrossPhasePO::getCrossId));
        }
    }
}
