package net.wanji.opt.cache;

import lombok.extern.slf4j.Slf4j;
import net.wanji.common.framework.Constants;
import net.wanji.opt.dao.mapper.CrossSchemeMapper;
import net.wanji.opt.po.base.CrossSchemePO;
import org.springframework.boot.CommandLineRunner;
import org.springframework.stereotype.Component;
import org.springframework.util.CollectionUtils;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author duanruiming
 * @date 2023/03/06 14:30
 */
@Component
@Slf4j
public class CrossSchemeInfoCache implements CommandLineRunner {

    @Resource
    CrossSchemeMapper crossSchemeMapper;

    /**
     * key:crossId_id  value:CrossSchemePO
     */
    private static Map<String, CrossSchemePO> crossSchemeInfoMap = new HashMap<>();

    public static Map<String, CrossSchemePO> getCrossSchemeInfosCache() {
        return crossSchemeInfoMap;
    }

    public static CrossSchemePO geteSchemePOCache(String key) {
        if (!crossSchemeInfoMap.isEmpty()) {
            return crossSchemeInfoMap.get(key);
        }
        return null;
    }

    public void refresh() {
        init();
    }

    @Override
    public void run(String... args) throws Exception {
        init();
    }

    private void init() {

        try {
            long start = System.currentTimeMillis();
            List<CrossSchemePO> crossSchemePOS = crossSchemeMapper.listCrossSchemeInfo(Constants.SystemParam.NULL, Constants.SystemParam.NULL, null);
            if (!CollectionUtils.isEmpty(crossSchemePOS)) {
                crossSchemePOS.forEach(crossSchemePO -> {
                    String crossId = crossSchemePO.getCrossId();
                    Integer schemeId = crossSchemePO.getId();
                    String key = String.join("_", crossId, String.valueOf(schemeId));
                    crossSchemeInfoMap.put(key, crossSchemePO);
                });
            }

            long end = System.currentTimeMillis();
            log.info("加载路口方案信息到缓存耗时：{}ms,条数据,size={}", (end - start), crossSchemeInfoMap.size());
        } catch (Exception e) {
            log.info("加载路口方案信息到缓存失败", e);
        }
    }
}
